package de.bananaco.webgui;

import java.io.File;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.configuration.file.YamlConfiguration;
import org.bukkit.entity.Player;
import org.bukkit.permissions.Permission;
import org.bukkit.permissions.PermissionDefault;
import org.bukkit.plugin.java.JavaPlugin;

public class WebGUI extends JavaPlugin {
	
	public static WebGUI instance;
	
	YamlConfiguration c;
	
	HashSet<String> allowed = new HashSet<String>();
	QueryServer qs;
	int port = 4545;
	String ip = "ANY";
	
	String username = "admin";
	String passhash = "0";
	
	public boolean onCommand(CommandSender sender, Command command, String label, String[] args) {
		if(sender instanceof Player) {
			Player player = (Player) sender;
			if(!player.hasPermission("bPermissions.gui")) {
				sender.sendMessage("Nope.");
				return true;
			}
		}
		if(args.length == 1) {
		String ip = args[0];
		sender.sendMessage(ip + " added to the list");
		allowed.add(ip);
		return true;
		}
		return false;
	}
	
	public void log(Object input) {
		String name = getDescription().getName();
		String version = getDescription().getVersion();
		
		System.out.println("["+name+" "+version+"] "+String.valueOf(input));
	}
	
	@Override
	public void onDisable() {
		qs.closeThis();
		log("Disabled");
	}

	@Override
	public void onEnable() {
		// Set the instance
		instance = this;
		
		setupPermissions();
		try {
			setupConfiguration();
		} catch (Exception e1) {
			e1.printStackTrace();
		}
		
		getServer().getPluginManager().addPermission(new Permission("bPermissions.gui", PermissionDefault.OP));
		qs = new QueryServer(ip, port);
		try {
			qs.startListener();
		} catch (Exception e) {
			e.printStackTrace();
		}
		qs.start();
		
		log("Enabled");
	}
	
	public void setupConfiguration() throws Exception {
	File file = new File("plugins/bPermissionsWebGUI/config.yml");
	// Fix NPE #112
	if(!file.exists()) {
		file.getParentFile().mkdirs();
		file.createNewFile();
	}
		
	c = new YamlConfiguration();
	c.load(file);
	
	List<String> template = new ArrayList<String>();
	template.add("localhost");
	template.add("127.0.0.1");
	
	List<String> allowed = c.getStringList("whitelist-ip");
	
	if(allowed != null && allowed.size() > 0) {
		for(String allow : allowed)
			this.allowed.add(allow);
	} else {
		allowed = new ArrayList<String>();
		allowed.add("127.0.0.1");
		allowed.add("localhost");
	}
				
	this.port = c.getInt("bind-port", 4545);
	this.ip = c.getString("bind-ip", "ANY");
	this.username = c.getString("username", username);
	String password = c.getString("password", "password");
	this.passhash = PassHash.hash(password.toCharArray());
	
	c.set("bind-port", port);
	c.set("bind-ip", ip);
	
	c.set("username", username);
	c.set("password", password);
	
	c.set("whitelist-ip", allowed);
	
	c.save(file);
	}
	
	public void setupPermissions() {
	try {
		String version = getServer().getPluginManager().getPlugin("bPermissions").getDescription().getVersion();
		log("bPermissions "+version+" detected, hooking in.");
	} catch (Exception e) {
		log("bPermissions not installed!");
	}
	}

}
